Store

Struct Store 

pub struct Store { /* private fields */ }
Main user-facing database handle.

Implementations

Source

impl Store

pub fn builder() -> StoreBuilder

Creates a store builder.

pub fn from_parts( driver: Arc<dyn Driver>, codec: Arc<dyn Codec>, namespace: Namespace, ) -> Self

Creates a store from parts.

pub async fn initialise(&self) -> Result<()>

Prepares the underlying driver for use.

pub async fn finalise(&self) -> Result<()>

Releases underlying driver resources.

pub fn namespace(&self) -> &Namespace

Returns the active namespace.

pub fn capabilities(&self) -> Capabilities

Returns the active driver capabilities.

pub async fn get<T, K>(&self, key: K) -> Result<Option<T>>

Reads a typed value from the default collection.

pub async fn set<T, K>(&self, key: K, value: &T) -> Result<()>

Writes a typed value to the default collection.

pub async fn delete<K>(&self, key: K) -> Result<bool>
where K: TryInto<Key>, YugenDbError: From<K::Error>,

Deletes a value from the default collection.

pub async fn exists<K>(&self, key: K) -> Result<bool>
where K: TryInto<Key>, YugenDbError: From<K::Error>,

Returns whether a key exists in the default collection.

pub async fn scan_prefix<T>( &self, prefix: impl Into<String>, ) -> Result<Vec<(Key, T)>>

Scans typed values by key prefix in the default collection.

pub fn collection<T, C>(&self, name: C) -> Result<Collection<T>>

Creates a typed collection handle.

pub async fn get_from_collection<T, K>( &self, collection: &CollectionName, key: K, ) -> Result<Option<T>>

Reads a typed value from a specific collection.

pub async fn set_in_collection<T, K>( &self, collection: &CollectionName, key: K, value: &T, ) -> Result<()>

Writes a typed value to a specific collection.

pub async fn set_in_collection_with_options<T, K>( &self, collection: &CollectionName, key: K, value: &T, options: WriteOptions, ) -> Result<()>

Writes a typed value to a specific collection with options.

pub async fn delete_from_collection<K>( &self, collection: &CollectionName, key: K, ) -> Result<bool>
where K: TryInto<Key>, YugenDbError: From<K::Error>,

Deletes a value from a specific collection.

pub async fn exists_in_collection<K>( &self, collection: &CollectionName, key: K, ) -> Result<bool>
where K: TryInto<Key>, YugenDbError: From<K::Error>,

Returns whether a key exists in a specific collection.

pub async fn scan_prefix_in_collection<T>( &self, collection: &CollectionName, prefix: impl Into<String>, ) -> Result<Vec<(Key, T)>>

Scans typed values by key prefix in a specific collection.