ValueMetadata

Struct ValueMetadata 

pub struct ValueMetadata {
    pub codec: String,
    pub created_at: DateTime<Utc>,
    pub updated_at: DateTime<Utc>,
    pub expires_at: Option<DateTime<Utc>>,
}
Metadata stored alongside a serialised value.

Fields

codec: String

Codec name used to serialise the value.

created_at: DateTime<Utc>

Creation timestamp in UTC.

updated_at: DateTime<Utc>

Last update timestamp in UTC.

expires_at: Option<DateTime<Utc>>

Expiry timestamp in UTC, when TTL is used.

Implementations

Source

impl ValueMetadata

pub fn new( codec: impl Into<String>, now: DateTime<Utc>, expires_at: Option<DateTime<Utc>>, ) -> Self

Creates metadata using the same timestamp for creation and update.

pub fn is_expired_at(&self, now: DateTime<Utc>) -> bool

Returns true when the metadata expiry time has passed.